@@ -53,6 +53,10 @@ func (csld CustomSingleLineDumper) LitterDump(w io.Writer) {
 }
 
 func TestSdump_primitives(t *testing.T) {
+	messages := make(chan string, 3)
+	sends := make(chan<- int64, 1)
+	receives := make(<-chan uint64)
+
 	runTests(t, "primitives", []interface{}{
 		false,
 		true,
@@ -68,6 +72,8 @@ func TestSdump_primitives(t *testing.T) {
 		uint(10),
 		float32(12.3),
 		float64(12.3),
+		float32(1.0),
+		float64(1.0),
 		complex64(12 + 10.5i),
 		complex128(-1.2 - 0.1i),
 		(func(v int) *int { return &v })(10),
@@ -85,6 +91,9 @@ func TestSdump_primitives(t *testing.T) {
 		interface{}(nil),
 		CustomMap{},
 		CustomMap(nil),
+		messages,
+		sends,
+		receives,
 	})
 }
 
@@ -234,6 +243,21 @@ func TestSdump_maps(t *testing.T) {
 	})
 }
 
+func TestSdump_RecursiveMaps(t *testing.T) {
+	mp := make(map[*RecursiveStruct]*RecursiveStruct)
+	k1 := &RecursiveStruct{}
+	k1.Ptr = k1
+	v1 := &RecursiveStruct{}
+	v1.Ptr = v1
+	k2 := &RecursiveStruct{}
+	k2.Ptr = k2
+	v2 := &RecursiveStruct{}
+	v2.Ptr = v2
+	mp[k1] = v1
+	mp[k2] = v2
+	runTests(t, "recursive_maps", mp)
+}
+
 var standardCfg = litter.Options{}
 
 func runTestWithCfg(t *testing.T, name string, cfg *litter.Options, cases ...interface{}) {
